==> mx-remastercc_23.6.tar.xz: mx-remastercc/translations/mx-remastercc_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MX Remastercc</source>
        <translation>MX Remastercc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>Persistence</source>
        <translation>Kararlı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;This tool allows you to rework an ISO while running Live. &lt;/span&gt;&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Remaster&lt;/span&gt; allows you to change files, applications and settings with the goal of producing a new master copy for storage or distribution. &lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Persistence&lt;/span&gt; allows you to retain data, settings and installed programs when the machine gets switched off for personal use.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Bu araç, Canlı çalıştırırken bir ISO üzerinde yeniden çalışmanıza olanak tanır. &lt;/span&gt;&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Yeniden Düzenleme&lt;/span&gt; depolama veya dağıtım için yeni bir ana kopya oluşturmak amacıyla dosyaları, uygulamaları ve ayarları değiştirmenize olanak tanır. &lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Kararlı&lt;/span&gt; kişisel kullanımda makine kapatıldığında verileri, ayarları ve yüklü programları saklamanızı sağlar.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>Display help </source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Quit application</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Basic operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Temel işlemler&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Remaster</source>
        <translation>Yeniden düzenle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Save root persistence</source>
        <translation>Kalıcı root’u kaydedin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Optional operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;İsteğe bağlı işlemler&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Configure live persistence</source>
        <translation>Çalışan kalıcı Yapılandırma</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="50"/>
        <location filename="../mainwindow.cpp" line="99"/>
        <source>MX Remaster Control Center</source>
        <translation>MX Yeniden Düzenleme Denetim Merkezi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="78"/>
        <source>MX RemasterCC</source>
        <translation>MX RemasterCC</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="98"/>
        <source>About MX Remaster Control Center</source>
        <translation>MX Yeniden Düzenleme Denetim Merkezi Hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>Version: </source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="101"/>
        <source>This program provides access to different remaster and persistence tools in MX Linux</source>
        <translation>Bu program MX Linux’taki farklı yeniden düzenleme ve kalıcı yapma araçlarına erişim sağlar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Telif Hakkı (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="104"/>
        <source>License</source>
        <translation>Ruhsat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="105"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="106"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
</context>
</TS>

==> mx-remastercc_23.7.tar.xz: mx-remastercc/translations/mx-remastercc_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MX Remastercc</source>
        <translation>MX Remastercc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>Persistence</source>
        <translation>Kararlı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;This tool allows you to rework an ISO while running Live. &lt;/span&gt;&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Remaster&lt;/span&gt; allows you to change files, applications and settings with the goal of producing a new master copy for storage or distribution. &lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Persistence&lt;/span&gt; allows you to retain data, settings and installed programs when the machine gets switched off for personal use.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Bu araç, Canlı çalıştırırken bir ISO üzerinde yeniden çalışmanıza olanak tanır. &lt;/span&gt;&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Yeniden Düzenleme&lt;/span&gt; depolama veya dağıtım için yeni bir ana kopya oluşturmak amacıyla dosyaları, uygulamaları ve ayarları değiştirmenize olanak tanır. &lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Kararlı&lt;/span&gt; kişisel kullanımda makine kapatıldığında verileri, ayarları ve yüklü programları saklamanızı sağlar.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>Display help </source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Quit application</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Basic operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Temel işlemler&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Remaster</source>
        <translation>Yeniden düzenle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Save root persistence</source>
        <translation>Kalıcı root’u kaydedin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Optional operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;İsteğe bağlı işlemler&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Configure live persistence</source>
        <translation>Çalışan kalıcı Yapılandırma</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="54"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>MX Remaster Control Center</source>
        <translation>MX Yeniden Düzenleme Denetim Merkezi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="82"/>
        <source>MX RemasterCC</source>
        <translation>MX RemasterCC</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="102"/>
        <source>About MX Remaster Control Center</source>
        <translation>MX Yeniden Düzenleme Denetim Merkezi Hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="104"/>
        <source>Version: </source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="105"/>
        <source>This program provides access to different remaster and persistence tools in MX Linux</source>
        <translation>Bu program MX Linux’taki farklı yeniden düzenleme ve kalıcı yapma araçlarına erişim sağlar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="107"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Telif Hakkı (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="108"/>
        <source>License</source>
        <translation>Lisans</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="128"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
</context>
</TS>
